==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/guestconfiguration/kotlin/inputs/GuestConfigurationNavigationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.guestconfiguration.kotlin.inputs

import com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs.builder
import com.pulumi.azurenative.guestconfiguration.kotlin.enums.AssignmentType
import com.pulumi.azurenative.guestconfiguration.kotlin.enums.Kind
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Guest configuration is an artifact that encapsulates DSC configuration and its dependencies. The artifact is a zip file containing DSC configuration (as MOF) and dependent resources and other dependencies like modules.
 * @property assignmentType Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
 * @property configurationParameter The configuration parameters for the guest configuration.
 * @property configurationProtectedParameter The protected configuration parameters for the guest configuration.
 * @property contentHash Combined hash of the guest configuration package and configuration parameters.
 * @property contentUri Uri of the storage where guest configuration package is uploaded.
 * @property kind Kind of the guest configuration. For example:DSC
 * @property name Name of the guest configuration.
 * @property version Version of the guest configuration.
 */
public data class GuestConfigurationNavigationArgs(
    public val assignmentType: Output<Either<String, AssignmentType>>? = null,
    public val configurationParameter: Output<List<ConfigurationParameterArgs>>? = null,
    public val configurationProtectedParameter: Output<List<ConfigurationParameterArgs>>? = null,
    public val contentHash: Output<String>? = null,
    public val contentUri: Output<String>? = null,
    public val kind: Output<Either<String, Kind>>? = null,
    public val name: Output<String>? = null,
    public val version: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs> {
    override fun toJava():
        com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs =
        com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs.builder()
            .assignmentType(
                assignmentType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .configurationParameter(
                configurationParameter?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .configurationProtectedParameter(
                configurationProtectedParameter?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .contentHash(contentHash?.applyValue({ args0 -> args0 }))
            .contentUri(contentUri?.applyValue({ args0 -> args0 }))
            .kind(
                kind?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestConfigurationNavigationArgs].
 */
@PulumiTagMarker
public class GuestConfigurationNavigationArgsBuilder internal constructor() {
    private var assignmentType: Output<Either<String, AssignmentType>>? = null

    private var configurationParameter: Output<List<ConfigurationParameterArgs>>? = null

    private var configurationProtectedParameter: Output<List<ConfigurationParameterArgs>>? = null

    private var contentHash: Output<String>? = null

    private var contentUri: Output<String>? = null

    private var kind: Output<Either<String, Kind>>? = null

    private var name: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("gktqsveooskuxbcn")
    public suspend fun assignmentType(`value`: Output<Either<String, AssignmentType>>) {
        this.assignmentType = value
    }

    /**
     * @param value The configuration parameters for the guest configuration.
     */
    @JvmName("vxxsgrxyetssbyep")
    public suspend fun configurationParameter(`value`: Output<List<ConfigurationParameterArgs>>) {
        this.configurationParameter = value
    }

    @JvmName("fqcvgtadmhxykrwv")
    public suspend fun configurationParameter(vararg values: Output<ConfigurationParameterArgs>) {
        this.configurationParameter = Output.all(values.asList())
    }

    /**
     * @param values The configuration parameters for the guest configuration.
     */
    @JvmName("vvsgmdudgcbwrkpw")
    public suspend fun configurationParameter(values: List<Output<ConfigurationParameterArgs>>) {
        this.configurationParameter = Output.all(values)
    }

    /**
     * @param value The protected configuration parameters for the guest configuration.
     */
    @JvmName("cwjmfbjycwkovgsb")
    public suspend
    fun configurationProtectedParameter(`value`: Output<List<ConfigurationParameterArgs>>) {
        this.configurationProtectedParameter = value
    }

    @JvmName("nrsnlaednyseslmr")
    public suspend fun configurationProtectedParameter(
        vararg
        values: Output<ConfigurationParameterArgs>,
    ) {
        this.configurationProtectedParameter = Output.all(values.asList())
    }

    /**
     * @param values The protected configuration parameters for the guest configuration.
     */
    @JvmName("ihqmhdwkltcrehdt")
    public suspend
    fun configurationProtectedParameter(values: List<Output<ConfigurationParameterArgs>>) {
        this.configurationProtectedParameter = Output.all(values)
    }

    /**
     * @param value Combined hash of the guest configuration package and configuration parameters.
     */
    @JvmName("atohjgsiwtytxdtp")
    public suspend fun contentHash(`value`: Output<String>) {
        this.contentHash = value
    }

    /**
     * @param value Uri of the storage where guest configuration package is uploaded.
     */
    @JvmName("fbycdrgdtntqihir")
    public suspend fun contentUri(`value`: Output<String>) {
        this.contentUri = value
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("emygsnitivdfegxf")
    public suspend fun kind(`value`: Output<Either<String, Kind>>) {
        this.kind = value
    }

    /**
     * @param value Name of the guest configuration.
     */
    @JvmName("ibdktmthakrllcct")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Version of the guest configuration.
     */
    @JvmName("hxxkkwaiiqrgtxce")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("idqcngjydinnnguj")
    public suspend fun assignmentType(`value`: Either<String, AssignmentType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assignmentType = mapped
    }

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("yudcrwwsvnppvfjq")
    public fun assignmentType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AssignmentType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.assignmentType = mapped
    }

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("pkojciaurwdremtk")
    public fun assignmentType(`value`: AssignmentType) {
        val toBeMapped = Either.ofRight<String, AssignmentType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.assignmentType = mapped
    }

    /**
     * @param value The configuration parameters for the guest configuration.
     */
    @JvmName("fwvleotpslnlchtj")
    public suspend fun configurationParameter(`value`: List<ConfigurationParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationParameter = mapped
    }

    /**
     * @param argument The configuration parameters for the guest configuration.
     */
    @JvmName("syifkqmgltucwcvq")
    public suspend
    fun configurationParameter(argument: List<suspend ConfigurationParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationParameter = mapped
    }

    /**
     * @param argument The configuration parameters for the guest configuration.
     */
    @JvmName("svboljoyjgtqvgbs")
    public suspend fun configurationParameter(
        vararg
        argument: suspend ConfigurationParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationParameter = mapped
    }

    /**
     * @param argument The configuration parameters for the guest configuration.
     */
    @JvmName("dtdiueiotlxqqynj")
    public suspend
    fun configurationParameter(argument: suspend ConfigurationParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ConfigurationParameterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.configurationParameter = mapped
    }

    /**
     * @param values The configuration parameters for the guest configuration.
     */
    @JvmName("uyqsijdafwkxgebw")
    public suspend fun configurationParameter(vararg values: ConfigurationParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.configurationParameter = mapped
    }

    /**
     * @param value The protected configuration parameters for the guest configuration.
     */
    @JvmName("rktupfjidikyfdec")
    public suspend fun configurationProtectedParameter(`value`: List<ConfigurationParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param argument The protected configuration parameters for the guest configuration.
     */
    @JvmName("ctunxtkcphncelha")
    public suspend
    fun configurationProtectedParameter(argument: List<suspend ConfigurationParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param argument The protected configuration parameters for the guest configuration.
     */
    @JvmName("steadttqwbkfrtbv")
    public suspend fun configurationProtectedParameter(
        vararg
        argument: suspend ConfigurationParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param argument The protected configuration parameters for the guest configuration.
     */
    @JvmName("ieqpsdxnhvwsbjvf")
    public suspend
    fun configurationProtectedParameter(argument: suspend ConfigurationParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ConfigurationParameterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param values The protected configuration parameters for the guest configuration.
     */
    @JvmName("ecpglcsgeuiwsnxl")
    public suspend fun configurationProtectedParameter(vararg values: ConfigurationParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param value Combined hash of the guest configuration package and configuration parameters.
     */
    @JvmName("vcmliwqnufwnqxyb")
    public suspend fun contentHash(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentHash = mapped
    }

    /**
     * @param value Uri of the storage where guest configuration package is uploaded.
     */
    @JvmName("rhamdvwskvdybdvi")
    public suspend fun contentUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentUri = mapped
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("yrfbjqtlbxrbbxfy")
    public suspend fun kind(`value`: Either<String, Kind>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("jpifokblbqbrojbn")
    public fun kind(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Kind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("xgwfoymwbvuouqby")
    public fun kind(`value`: Kind) {
        val toBeMapped = Either.ofRight<String, Kind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the guest configuration.
     */
    @JvmName("htkfkrgbmsmhncea")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Version of the guest configuration.
     */
    @JvmName("vcuelsulioamenxa")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): GuestConfigurationNavigationArgs = GuestConfigurationNavigationArgs(
        assignmentType = assignmentType,
        configurationParameter = configurationParameter,
        configurationProtectedParameter = configurationProtectedParameter,
        contentHash = contentHash,
        contentUri = contentUri,
        kind = kind,
        name = name,
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/guestconfiguration/kotlin/inputs/GuestConfigurationNavigationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.guestconfiguration.kotlin.inputs

import com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs.builder
import com.pulumi.azurenative.guestconfiguration.kotlin.enums.AssignmentType
import com.pulumi.azurenative.guestconfiguration.kotlin.enums.Kind
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Guest configuration is an artifact that encapsulates DSC configuration and its dependencies. The artifact is a zip file containing DSC configuration (as MOF) and dependent resources and other dependencies like modules.
 * @property assignmentType Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
 * @property configurationParameter The configuration parameters for the guest configuration.
 * @property configurationProtectedParameter The protected configuration parameters for the guest configuration.
 * @property contentHash Combined hash of the guest configuration package and configuration parameters.
 * @property contentUri Uri of the storage where guest configuration package is uploaded.
 * @property kind Kind of the guest configuration. For example:DSC
 * @property name Name of the guest configuration.
 * @property version Version of the guest configuration.
 */
public data class GuestConfigurationNavigationArgs(
    public val assignmentType: Output<Either<String, AssignmentType>>? = null,
    public val configurationParameter: Output<List<ConfigurationParameterArgs>>? = null,
    public val configurationProtectedParameter: Output<List<ConfigurationParameterArgs>>? = null,
    public val contentHash: Output<String>? = null,
    public val contentUri: Output<String>? = null,
    public val kind: Output<Either<String, Kind>>? = null,
    public val name: Output<String>? = null,
    public val version: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs> {
    override fun toJava():
        com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs =
        com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs.builder()
            .assignmentType(
                assignmentType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .configurationParameter(
                configurationParameter?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .configurationProtectedParameter(
                configurationProtectedParameter?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .contentHash(contentHash?.applyValue({ args0 -> args0 }))
            .contentUri(contentUri?.applyValue({ args0 -> args0 }))
            .kind(
                kind?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestConfigurationNavigationArgs].
 */
@PulumiTagMarker
public class GuestConfigurationNavigationArgsBuilder internal constructor() {
    private var assignmentType: Output<Either<String, AssignmentType>>? = null

    private var configurationParameter: Output<List<ConfigurationParameterArgs>>? = null

    private var configurationProtectedParameter: Output<List<ConfigurationParameterArgs>>? = null

    private var contentHash: Output<String>? = null

    private var contentUri: Output<String>? = null

    private var kind: Output<Either<String, Kind>>? = null

    private var name: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("fxsxgvvpfrtywomb")
    public suspend fun assignmentType(`value`: Output<Either<String, AssignmentType>>) {
        this.assignmentType = value
    }

    /**
     * @param value The configuration parameters for the guest configuration.
     */
    @JvmName("kyuistftnnbqgwmn")
    public suspend fun configurationParameter(`value`: Output<List<ConfigurationParameterArgs>>) {
        this.configurationParameter = value
    }

    @JvmName("wojstpxtmgbultio")
    public suspend fun configurationParameter(vararg values: Output<ConfigurationParameterArgs>) {
        this.configurationParameter = Output.all(values.asList())
    }

    /**
     * @param values The configuration parameters for the guest configuration.
     */
    @JvmName("rhpcjvwfkgobhvcr")
    public suspend fun configurationParameter(values: List<Output<ConfigurationParameterArgs>>) {
        this.configurationParameter = Output.all(values)
    }

    /**
     * @param value The protected configuration parameters for the guest configuration.
     */
    @JvmName("uretjiushyngtnqd")
    public suspend
    fun configurationProtectedParameter(`value`: Output<List<ConfigurationParameterArgs>>) {
        this.configurationProtectedParameter = value
    }

    @JvmName("hblymuukvusoweck")
    public suspend fun configurationProtectedParameter(
        vararg
        values: Output<ConfigurationParameterArgs>,
    ) {
        this.configurationProtectedParameter = Output.all(values.asList())
    }

    /**
     * @param values The protected configuration parameters for the guest configuration.
     */
    @JvmName("ktcwgmsvovmsxnoe")
    public suspend
    fun configurationProtectedParameter(values: List<Output<ConfigurationParameterArgs>>) {
        this.configurationProtectedParameter = Output.all(values)
    }

    /**
     * @param value Combined hash of the guest configuration package and configuration parameters.
     */
    @JvmName("fxpxwckvhcdmecyw")
    public suspend fun contentHash(`value`: Output<String>) {
        this.contentHash = value
    }

    /**
     * @param value Uri of the storage where guest configuration package is uploaded.
     */
    @JvmName("gomfbqfxxiqoyltr")
    public suspend fun contentUri(`value`: Output<String>) {
        this.contentUri = value
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("xrjrxnlmrjbyndhv")
    public suspend fun kind(`value`: Output<Either<String, Kind>>) {
        this.kind = value
    }

    /**
     * @param value Name of the guest configuration.
     */
    @JvmName("wgdjoydbapodiuuy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Version of the guest configuration.
     */
    @JvmName("ktbcvsqotdpdtlcq")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("stiukmythvupfecm")
    public suspend fun assignmentType(`value`: Either<String, AssignmentType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assignmentType = mapped
    }

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("vcjqnlbikqumltnp")
    public fun assignmentType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AssignmentType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.assignmentType = mapped
    }

    /**
     * @param value Specifies the assignment type and execution of the configuration. Possible values are Audit, DeployAndAutoCorrect, ApplyAndAutoCorrect and ApplyAndMonitor.
     */
    @JvmName("haklhoawogvqanjj")
    public fun assignmentType(`value`: AssignmentType) {
        val toBeMapped = Either.ofRight<String, AssignmentType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.assignmentType = mapped
    }

    /**
     * @param value The configuration parameters for the guest configuration.
     */
    @JvmName("xojffmdarlatpbai")
    public suspend fun configurationParameter(`value`: List<ConfigurationParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationParameter = mapped
    }

    /**
     * @param argument The configuration parameters for the guest configuration.
     */
    @JvmName("dirbevvipoegpbkp")
    public suspend
    fun configurationParameter(argument: List<suspend ConfigurationParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationParameter = mapped
    }

    /**
     * @param argument The configuration parameters for the guest configuration.
     */
    @JvmName("jfyrlkjhlgrwbigo")
    public suspend fun configurationParameter(
        vararg
        argument: suspend ConfigurationParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationParameter = mapped
    }

    /**
     * @param argument The configuration parameters for the guest configuration.
     */
    @JvmName("mhygmjreeaqnglur")
    public suspend
    fun configurationParameter(argument: suspend ConfigurationParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ConfigurationParameterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.configurationParameter = mapped
    }

    /**
     * @param values The configuration parameters for the guest configuration.
     */
    @JvmName("neyeraccstbovxth")
    public suspend fun configurationParameter(vararg values: ConfigurationParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.configurationParameter = mapped
    }

    /**
     * @param value The protected configuration parameters for the guest configuration.
     */
    @JvmName("awdrgqipptoidgtx")
    public suspend fun configurationProtectedParameter(`value`: List<ConfigurationParameterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param argument The protected configuration parameters for the guest configuration.
     */
    @JvmName("wxakjccdncndyabg")
    public suspend
    fun configurationProtectedParameter(argument: List<suspend ConfigurationParameterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param argument The protected configuration parameters for the guest configuration.
     */
    @JvmName("nwdhdipplwqmawib")
    public suspend fun configurationProtectedParameter(
        vararg
        argument: suspend ConfigurationParameterArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationParameterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param argument The protected configuration parameters for the guest configuration.
     */
    @JvmName("jjnwcuuxyerqtdbm")
    public suspend
    fun configurationProtectedParameter(argument: suspend ConfigurationParameterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ConfigurationParameterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param values The protected configuration parameters for the guest configuration.
     */
    @JvmName("ofkheigvdetgevse")
    public suspend fun configurationProtectedParameter(vararg values: ConfigurationParameterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.configurationProtectedParameter = mapped
    }

    /**
     * @param value Combined hash of the guest configuration package and configuration parameters.
     */
    @JvmName("dnrvrafmgurdxwft")
    public suspend fun contentHash(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentHash = mapped
    }

    /**
     * @param value Uri of the storage where guest configuration package is uploaded.
     */
    @JvmName("eiinbbpslebftfkh")
    public suspend fun contentUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentUri = mapped
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("otratrfvqqibfema")
    public suspend fun kind(`value`: Either<String, Kind>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("arpuqeghspuwnxmt")
    public fun kind(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Kind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Kind of the guest configuration. For example:DSC
     */
    @JvmName("vriheuslrwmoojvj")
    public fun kind(`value`: Kind) {
        val toBeMapped = Either.ofRight<String, Kind>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the guest configuration.
     */
    @JvmName("rpkylhxpcwdirlgs")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Version of the guest configuration.
     */
    @JvmName("mlrjdqsiqbesgxww")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): GuestConfigurationNavigationArgs = GuestConfigurationNavigationArgs(
        assignmentType = assignmentType,
        configurationParameter = configurationParameter,
        configurationProtectedParameter = configurationProtectedParameter,
        contentHash = contentHash,
        contentUri = contentUri,
        kind = kind,
        name = name,
        version = version,
    )
}
